==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/CascadeToExistingArrayListMember.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;
using com.db4o.foundation;
using j4o.lang;
using j4o.util;
using com.db4o;
namespace com.db4o.test 
{

	public class CascadeToExistingArrayListMember 
	{
      
		public CascadeToExistingArrayListMember () : base() 
		{
		}
		public ArrayList vec;
      
		public void configure() 
		{
			Db4o.configure().objectClass(j4o.lang.Class.getClassForObject(this).getName()).cascadeOnUpdate(true);
		}
      
		public void store() 
		{
			Tester.deleteAllInstances(new Atom());
			Tester.deleteAllInstances(this);
			CascadeToExistingArrayListMember cev1 = new CascadeToExistingArrayListMember();
			cev1.vec = new ArrayList();
			Atom atom1 = new Atom("one");
			Tester.store(atom1);
			cev1.vec.Add(atom1);
			Tester.store(cev1);
		}
      
		public void test() 
		{
			Tester.forEach(new CascadeToExistingArrayListMember(), new MyVisitorE1());
			Tester.reOpen();
			Tester.forEach(new CascadeToExistingArrayListMember(), new MyVisitorE2());
			Tester.forEach(new CascadeToExistingArrayListMember(), new MyVisitorE3());
			Tester.reOpen();
			Tester.forEach(new CascadeToExistingArrayListMember(), new MyVisitorE4());
		}
	}

	public class MyVisitorE1:Visitor4
	{
		public void visit(Object obj) 
		{
			CascadeToExistingArrayListMember cev1 = (CascadeToExistingArrayListMember)obj;
			Atom atom1 = (Atom)cev1.vec[0];
			atom1.name = "two";
			Tester.store(cev1);
			atom1.name = "three";
			Tester.store(cev1);
		}
	}
	public class MyVisitorE2:Visitor4
	{
		public void visit(Object obj) 
		{
			CascadeToExistingArrayListMember cev1 = (CascadeToExistingArrayListMember)obj;
			Atom atom1 = (Atom)cev1.vec[0];
			Tester.ensure(atom1.name.Equals("three"));
			Tester.ensureOccurrences(atom1, 1);
		}
	}
	public class MyVisitorE3:Visitor4
	{
		public void visit(Object obj) 
		{
			CascadeToExistingArrayListMember cev1 = (CascadeToExistingArrayListMember)obj;
			Atom atom1 = (Atom)cev1.vec[0];
			atom1.name = "four";
			Tester.store(cev1);
		}
	}

	public class MyVisitorE4:Visitor4
	{
		public void visit(Object obj) 
		{
			CascadeToExistingArrayListMember cev1 = (CascadeToExistingArrayListMember)obj;
			Atom atom1 = (Atom)cev1.vec[0];
			Tester.ensure(atom1.name.Equals("four"));
			Tester.ensureOccurrences(atom1, 1);
		}
	}



}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/CascadeToExistingArrayListMember.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;
using com.db4o.foundation;
using j4o.lang;
using j4o.util;
using com.db4o;
namespace com.db4o.test 
{

	public class CascadeToExistingArrayListMember 
	{
      
		public CascadeToExistingArrayListMember () : base() 
		{
		}
		public ArrayList vec;
      
		public void Configure() 
		{
			Db4o.Configure().ObjectClass(j4o.lang.Class.GetClassForObject(this).GetName()).CascadeOnUpdate(true);
		}
      
		public void Store() 
		{
			Tester.DeleteAllInstances(new Atom());
			Tester.DeleteAllInstances(this);
			CascadeToExistingArrayListMember cev1 = new CascadeToExistingArrayListMember();
			cev1.vec = new ArrayList();
			Atom atom1 = new Atom("one");
			Tester.Store(atom1);
			cev1.vec.Add(atom1);
			Tester.Store(cev1);
		}
      
		public void Test() 
		{
			Tester.ForEach(new CascadeToExistingArrayListMember(), new MyVisitorE1());
			Tester.ReOpen();
			Tester.ForEach(new CascadeToExistingArrayListMember(), new MyVisitorE2());
			Tester.ForEach(new CascadeToExistingArrayListMember(), new MyVisitorE3());
			Tester.ReOpen();
			Tester.ForEach(new CascadeToExistingArrayListMember(), new MyVisitorE4());
		}
	}

	public class MyVisitorE1:Visitor4
	{
		public void Visit(Object obj) 
		{
			CascadeToExistingArrayListMember cev1 = (CascadeToExistingArrayListMember)obj;
			Atom atom1 = (Atom)cev1.vec[0];
			atom1.name = "two";
			Tester.Store(cev1);
			atom1.name = "three";
			Tester.Store(cev1);
		}
	}
	public class MyVisitorE2:Visitor4
	{
		public void Visit(Object obj) 
		{
			CascadeToExistingArrayListMember cev1 = (CascadeToExistingArrayListMember)obj;
			Atom atom1 = (Atom)cev1.vec[0];
			Tester.Ensure(atom1.name.Equals("three"));
			Tester.EnsureOccurrences(atom1, 1);
		}
	}
	public class MyVisitorE3:Visitor4
	{
		public void Visit(Object obj) 
		{
			CascadeToExistingArrayListMember cev1 = (CascadeToExistingArrayListMember)obj;
			Atom atom1 = (Atom)cev1.vec[0];
			atom1.name = "four";
			Tester.Store(cev1);
		}
	}

	public class MyVisitorE4:Visitor4
	{
		public void Visit(Object obj) 
		{
			CascadeToExistingArrayListMember cev1 = (CascadeToExistingArrayListMember)obj;
			Atom atom1 = (Atom)cev1.vec[0];
			Tester.Ensure(atom1.name.Equals("four"));
			Tester.EnsureOccurrences(atom1, 1);
		}
	}



}
